pub type AgentClient = Client<AgentProtocol>;Expand description
Low-level agent connection with native, encoded, raw, stream, and packet APIs.
Aliased Type
pub struct AgentClient { /* private fields */ }pub type AgentClient = Client<AgentProtocol>;Low-level agent connection with native, encoded, raw, stream, and packet APIs.
pub struct AgentClient { /* private fields */ }