Message

Struct Message 

pub struct Message {
    pub v: u8,
    pub t: String,
    pub id: u32,
    pub flags: u8,
    pub p: Vec<u8>,
    /* private fields */
}
Decoded message with its original frame retained for unknown fields/forwarding.

Fields

v: u8

Actual envelope generation.

t: String

Actual wire name, including unknown future names.

id: u32

Frame correlation ID.

flags: u8

Actual frame flags.

p: Vec<u8>

Original encoded payload.

Implementations

Source

impl Message

pub fn new(frame: RawFrame, envelope: Envelope) -> Message

Construct a view for a custom envelope codec without losing original bytes.

pub fn payload<T>(&self) -> Result<T, ClientError>

Decode a known payload without narrowing the incoming message namespace.

pub fn raw(&self) -> &RawFrame

Inspect the original frame, including unknown envelope fields.

pub fn into_raw(self) -> RawFrame

Recover the exact received frame for forwarding.