pub struct TypedMessage<T> {
pub message_type: MessageType,
pub payload: T,
}Expand description
A message described by protocol type and a native serializable payload.
Use this form when Rust should CBOR-encode the payload. The payload type must
serialize to the shape expected by microsandbox-protocol for
message_type.
Fields
message_type: MessageTypeProtocol message type.
payload: TNative payload to CBOR-encode.
Implementations
Sourceimpl<T> TypedMessage<T>
impl<T> TypedMessage<T>
Sourcepub fn new(message_type: MessageType, payload: T) -> Self
pub fn new(message_type: MessageType, payload: T) -> Self
Create a typed message from a protocol type and native payload.